ClearState

Struct ClearState 

pub struct ClearState {
    pub red: Option<f32>,
    pub green: Option<f32>,
    pub blue: Option<f32>,
    pub alpha: Option<f32>,
    pub depth: Option<f32>,
}
Defines which channels (red, green, blue, alpha and depth) to clear when starting to write to a RenderTarget. If None then the channel is not cleared and if Some(value) the channel is cleared to that value (the value must be between 0 and 1).

Fields

red: Option<f32>

Defines the clear value for the red channel.

green: Option<f32>

Defines the clear value for the green channel.

blue: Option<f32>

Defines the clear value for the blue channel.

alpha: Option<f32>

Defines the clear value for the alpha channel.

depth: Option<f32>

Defines the clear value for the depth channel. A value of 1 means a depth value equal to the far plane and 0 means a depth value equal to the near plane.

Implementations

Source

impl ClearState

pub const fn none() -> Self

Nothing will be cleared.

pub const fn depth(depth: f32) -> Self

The depth will be cleared to the given value.

pub const fn color(red: f32, green: f32, blue: f32, alpha: f32) -> Self

The color channels (red, green, blue and alpha) will be cleared to the given values.

pub const fn color_and_depth( red: f32, green: f32, blue: f32, alpha: f32, depth: f32, ) -> Self

Both the color channels (red, green, blue and alpha) and depth will be cleared to the given values.