Struct three_d::core::ElementBuffer [−][src]
pub struct ElementBuffer { /* fields omitted */ }Expand description
A buffer containing indices for rendering, see for example draw_elements. Also known as an index buffer.
Implementations
impl ElementBuffer[src]
impl ElementBuffer[src]pub fn new_with_u32(
context: &Context,
data: &[u32]
) -> Result<ElementBuffer, Error>[src]
pub fn new_with_u32(
context: &Context,
data: &[u32]
) -> Result<ElementBuffer, Error>[src]Creates a new element buffer and fills it with the given indices.
pub fn fill_with_u32(&mut self, data: &[u32])[src]
pub fn fill_with_u32(&mut self, data: &[u32])[src]Fills the buffer with the given indices.