Texture2D

Struct Texture2D 

pub struct Texture2D { /* private fields */ }
A 2D texture, basically an image that is transferred to the GPU.

Implementations

Source

impl Texture2D

pub fn new(context: &Context, cpu_texture: &CpuTexture) -> Self

Construcs a new texture with the given data.

Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.

pub fn new_empty<T: TextureDataType>( context: &Context, width: u32, height: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, ) -> Self

Constructs a new empty 2D texture with the given parameters. The format is determined by the generic TextureDataType parameter (for example, if [u8; 4] is specified, the format is RGBA and the data type is byte).

Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.

pub fn fill<T: TextureDataType>(&self, data: &[T])

Fills this texture with the given data and generate mip maps if specified at construction.

Panic

Will panic if the length of the data does not correspond to the width, height and format specified at construction. It is therefore necessary to create a new texture if the texture size or format has changed.

pub fn as_color_target(&self, mip_level: Option<u32>) -> ColorTarget<'_>

Returns a ColorTarget which can be used to clear, write to and read from the given mip level of this texture. Combine this together with a DepthTarget with RenderTarget::new to be able to write to both a depth and color target at the same time. If None is specified as the mip level, the 0 level mip level is used and mip maps are generated after a write operation if a mip map filter is specified. Otherwise, the given mip level is used and no mip maps are generated.

Note: DepthTest is disabled if not also writing to a depth texture.

pub fn width(&self) -> u32

The width of this texture.

pub fn height(&self) -> u32

The height of this texture.

pub fn number_of_mip_maps(&self) -> u32

The number of mip maps of this texture.

pub unsafe fn new_unchecked<T: TextureDataType>( context: &Context, width: u32, height: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, callback: impl FnOnce(&Self), ) -> Self

Creates a new texture where it is up to the caller to allocate and transfer data to the GPU using low-level context calls inside the callback. This function binds the texture and sets the parameters before calling the callback and generates mip maps afterwards.

Safety

This function is unsafe and should only be used in special cases, for example when you have an uncommon source of data or the data is in a special format like sRGB.