pub struct Texture2DArray { /* private fields */ }Expand description
A array of 2D color textures that can be rendered into.
Note: DepthTest is disabled if not also writing to a DepthTarget. Use a RenderTarget to write to both color and depth.
Implementations
Sourceimpl Texture2DArray
impl Texture2DArray
Sourcepub fn new(context: &Context, cpu_textures: &[&CpuTexture]) -> Self
pub fn new(context: &Context, cpu_textures: &[&CpuTexture]) -> Self
Creates a new texture array from the given CpuTextures. All of the cpu textures must contain data with the same TextureDataType and the same width and height.
Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.
Sourcepub fn new_empty<T: TextureDataType>(
context: &Context,
width: u32,
height: u32,
depth: u32,
min_filter: Interpolation,
mag_filter: Interpolation,
mipmap: Option<Mipmap>,
wrap_s: Wrapping,
wrap_t: Wrapping,
) -> Self
pub fn new_empty<T: TextureDataType>( context: &Context, width: u32, height: u32, depth: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, ) -> Self
Creates a new array of 2D textures.
Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.
Sourcepub fn fill<T: TextureDataType>(&self, data: &[&[T]])
pub fn fill<T: TextureDataType>(&self, data: &[&[T]])
Fills the texture array with the given pixel data and generate mip maps if specified at construction.
Panic
Will panic if the data does not correspond to the width, height, depth and format specified at construction. It is therefore necessary to create a new texture if the texture size or format has changed.
Sourcepub fn fill_layer<T: TextureDataType>(&self, layer: u32, data: &[T])
pub fn fill_layer<T: TextureDataType>(&self, layer: u32, data: &[T])
Fills the given layer in the texture array with the given pixel data and generate mip maps if specified at construction.
Panic
Will panic if the layer number is bigger than the number of layers or if the data does not correspond to the width, height and format specified at construction. It is therefore necessary to create a new texture if the texture size or format has changed.
Sourcepub fn as_color_target<'a>(
&'a self,
layers: &'a [u32],
mip_level: Option<u32>,
) -> ColorTarget<'a>
pub fn as_color_target<'a>( &'a self, layers: &'a [u32], mip_level: Option<u32>, ) -> ColorTarget<'a>
Returns a ColorTarget which can be used to clear, write to and read from the given layers and mip level of this texture.
Combine this together with a DepthTarget with RenderTarget::new to be able to write to both a depth and color target at the same time.
If None is specified as the mip level, the 0 level mip level is used and mip maps are generated after a write operation if a mip map filter is specified.
Otherwise, the given mip level is used and no mip maps are generated.
Note: DepthTest is disabled if not also writing to a depth texture.
Sourcepub fn number_of_mip_maps(&self) -> u32
pub fn number_of_mip_maps(&self) -> u32
The number of mip maps of this texture.
Sourcepub unsafe fn new_unchecked<T: TextureDataType>(
context: &Context,
width: u32,
height: u32,
depth: u32,
min_filter: Interpolation,
mag_filter: Interpolation,
mipmap: Option<Mipmap>,
wrap_s: Wrapping,
wrap_t: Wrapping,
callback: impl FnOnce(&Self),
) -> Self
pub unsafe fn new_unchecked<T: TextureDataType>( context: &Context, width: u32, height: u32, depth: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, callback: impl FnOnce(&Self), ) -> Self
Creates a new texture where it is up to the caller to allocate and transfer data to the GPU using low-level context calls inside the callback. This function binds the texture and sets the parameters before calling the callback and generates mip maps afterwards.
Safety
This function is unsafe and should only be used in special cases, for example when you have an uncommon source of data or the data is in a special format like sRGB.