Texture3D

Struct Texture3D 

pub struct Texture3D { /* private fields */ }
A 3D color texture.

Implementations

Source

impl Texture3D

pub fn new(context: &Context, cpu_texture: &CpuTexture3D) -> Self

Construcs a new 3D texture with the given data.

Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.

pub fn new_empty<T: TextureDataType>( context: &Context, width: u32, height: u32, depth: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, wrap_r: Wrapping, ) -> Self

Creates a new empty 3D color texture.

Note: Mip maps will not be generated for RGB16F and RGB32F format, even if mip_map_filter is specified.

pub fn fill<T: TextureDataType>(&self, data: &[T])

Fills this texture with the given data and generate mip maps if specified at construction.

Panic

Will panic if the length of the data does not correspond to the width, height, depth and format specified at construction. It is therefore necessary to create a new texture if the texture size or format has changed.

pub fn width(&self) -> u32

The width of this texture.

pub fn height(&self) -> u32

The height of this texture.

pub fn depth(&self) -> u32

The depth of this texture.

pub fn number_of_mip_maps(&self) -> u32

The number of mip maps of this texture.

pub unsafe fn new_unchecked<T: TextureDataType>( context: &Context, width: u32, height: u32, depth: u32, min_filter: Interpolation, mag_filter: Interpolation, mipmap: Option<Mipmap>, wrap_s: Wrapping, wrap_t: Wrapping, wrap_r: Wrapping, callback: impl FnOnce(&Self), ) -> Self

Creates a new texture where it is up to the caller to allocate and transfer data to the GPU using low-level context calls inside the callback. This function binds the texture and sets the parameters before calling the callback and generates mip maps afterwards.

Safety

This function is unsafe and should only be used in special cases, for example when you have an uncommon source of data or the data is in a special format like sRGB.