Trait three_d::core::TextureArray [−][src]
pub trait TextureArray {
fn bind(&self, location: u32);
fn width(&self) -> usize;
fn height(&self) -> usize;
fn depth(&self) -> usize;
}Expand description
A texture array that can be sampled in a fragment shader (see use_texture_array).
Required methods
fn bind(&self, location: u32)[src]
Binds this texture array to the current shader program.
fn width(&self) -> usize[src]
The width of this texture.
fn height(&self) -> usize[src]
The height of this texture.
fn depth(&self) -> usize[src]
The depth of this texture, ie. the number of layers.