Trait three_d::core::TextureCube [−][src]
pub trait TextureCube {
fn bind(&self, location: u32);
fn width(&self) -> usize;
fn height(&self) -> usize;
}Expand description
A texture cube that can be sampled in a fragment shader (see use_texture_cube).
Required methods
fn bind(&self, location: u32)[src]
Binds this texture cube to the current shader program.
fn width(&self) -> usize[src]
The width of one of the sides of this texture.
fn height(&self) -> usize[src]
The height of one of the sides of this texture.
Implementors
impl<T: TextureValueType> TextureCube for TextureCubeMap<T>[src]
impl<T: TextureValueType> TextureCube for TextureCubeMap<T>[src]