Struct three_d::light::AmbientLight [−][src]
A light which shines equally on all parts of any surface.
Fields
color: Vec3intensity: f32A light which shines equally on all parts of any surface.
color: Vec3intensity: f32impl RefUnwindSafe for AmbientLightimpl Send for AmbientLightimpl Sync for AmbientLightimpl Unpin for AmbientLightimpl UnwindSafe for AmbientLight