Struct three_d::object::ParticleData [−][src]
Used to define the initial position and velocity of a particle in Particles.
Fields
start_position: Vec3start_velocity: Vec3Used to define the initial position and velocity of a particle in Particles.
start_position: Vec3start_velocity: Vec3impl RefUnwindSafe for ParticleDataimpl Send for ParticleDataimpl Sync for ParticleDataimpl Unpin for ParticleDataimpl UnwindSafe for ParticleData