Module three_d::phong [−][src]
Adds functionality for rendering objects based on the phong reflection model.
Structs
| PhongDeferredPipeline | Deferred pipeline based on the Phong reflection model supporting a performance-limited amount of directional, point and spot lights with shadows. |
| PhongInstancedMesh | Extends a InstancedMesh by adding functionality to render it based on the Phong shading model. |
| PhongMaterial | A material used for shading an object based on the Phong shading model. |
| PhongMesh | Extends a Mesh by adding functionality to render it based on the Phong shading model. |
Enums
| ColorSource | The source of color on an object, either a fixed value or a texture. |
| DebugType | Used for debug purposes. |
Traits
| PhongGeometry | Used for deferred Phong rendering. Implemented by PhongMesh and PhongInstancedMesh. |