pub enum Key {
Show 98 variants
ArrowDown,
ArrowLeft,
ArrowRight,
ArrowUp,
Escape,
Tab,
Backspace,
Enter,
Space,
Insert,
Delete,
Home,
End,
PageUp,
PageDown,
Snapshot,
Mute,
VolumeDown,
VolumeUp,
Copy,
Paste,
Cut,
Equals,
Minus,
Plus,
Num0,
Num1,
Num2,
Num3,
Num4,
Num5,
Num6,
Num7,
Num8,
Num9,
A,
B,
C,
D,
E,
F,
G,
H,
I,
J,
K,
L,
M,
N,
O,
P,
Q,
R,
S,
T,
U,
V,
W,
X,
Y,
Z,
F1,
F2,
F3,
F4,
F5,
F6,
F7,
F8,
F9,
F10,
F11,
F12,
F13,
F14,
F15,
F16,
F17,
F18,
F19,
F20,
F21,
F22,
F23,
F24,
Apostrophe,
Asterisk,
Backslash,
Caret,
Colon,
Comma,
Grave,
LBracket,
Period,
RBracket,
Semicolon,
Slash,
Underline,
}Expand description
Keyboard key input.
Variants
ArrowDown
ArrowLeft
ArrowRight
ArrowUp
Escape
Tab
Backspace
Enter
Space
Insert
Delete
Home
End
PageUp
PageDown
Snapshot
Print Screen/SysRq.
Mute
VolumeDown
VolumeUp
Copy
Paste
Cut
Equals
=
Minus
-
Plus
+
Num0
Either from the main row or from the numpad.
Num1
Either from the main row or from the numpad.
Num2
Either from the main row or from the numpad.
Num3
Either from the main row or from the numpad.
Num4
Either from the main row or from the numpad.
Num5
Either from the main row or from the numpad.
Num6
Either from the main row or from the numpad.
Num7
Either from the main row or from the numpad.
Num8
Either from the main row or from the numpad.
Num9
Either from the main row or from the numpad.
A
B
C
D
E
F
G
H
I
J
K
L
M
N
O
P
Q
R
S
T
U
V
W
X
Y
Z
F1
F2
F3
F4
F5
F6
F7
F8
F9
F10
F11
F12
F13
F14
F15
F16
F17
F18
F19
F20
F21
F22
F23
F24
Apostrophe
'
Asterisk
*
Backslash
\
Caret
^
Colon
:
Comma
,
Grave
`
LBracket
[
Period
.
RBracket
]
Semicolon
;
Slash
/
Underline
_