pub struct PhysicalPoint {
pub x: f32,
pub y: f32,
}Expand description
A pixel coordinate in physical pixels, where x is on the horizontal axis with zero being at the left edge
and y is on the vertical axis with zero being at bottom edge.
Fields
x: f32The horizontal pixel distance from the left edge.
y: f32The vertical pixel distance from the bottom edge.