apply_screen_effect

Function apply_screen_effect 

pub fn apply_screen_effect(
    context: &Context,
    effect: impl Effect,
    viewer: impl Viewer,
    lights: &[&dyn Light],
    color_texture: Option<ColorTexture<'_>>,
    depth_texture: Option<DepthTexture<'_>>,
)
Apply the given Effect to the entire sceen. Must be called in the callback given as input to a RenderTarget, ColorTarget or DepthTarget write method. Use an empty array for the lights argument, if the effect does not require lights to be rendered.