Struct three_d::renderer::geometry::KeyFrameAnimation
source · pub struct KeyFrameAnimation {
pub name: Option<String>,
pub key_frames: Vec<(Matrix4<f32>, Arc<KeyFrames>)>,
}Expand description
A set of key frames and transformations associated with a specific animation for a specific Primitive.
Fields
name: Option<String>Optional name of the animation.
Can be used to distinguish between different types of animations for the same Primitive, for example between a “walk” and a “run” animation.
key_frames: Vec<(Matrix4<f32>, Arc<KeyFrames>)>A list of KeyFrames and transformations which are the result of traversing a Scene from root to the leaves.
Implementations
sourceimpl KeyFrameAnimation
impl KeyFrameAnimation
sourcepub fn transformation(&self, time: f32) -> Matrix4<f32>
pub fn transformation(&self, time: f32) -> Matrix4<f32>
Calculates a transformation for this animation at the given time.