pub struct KeyFrames {
    pub loop_time: Option<f32>,
    pub interpolation: Interpolation,
    pub times: Vec<f32>,
    pub rotations: Option<Vec<Quaternion<f32>>>,
    pub translations: Option<Vec<Vector3<f32>>>,
    pub scales: Option<Vec<Vector3<f32>>>,
    pub weights: Option<Vec<Vec<f32>>>,
}
Contains a set of key frames for rotations, translations, scales and morph weights.

Fields

loop_time: Option<f32>

Optional time where the animation repeats itself.

interpolation: Interpolation

The type of interpolation used in between the key frames.

times: Vec<f32>

The time value for each key frame.

rotations: Option<Vec<Quaternion<f32>>>

The rotation for each key frame.

translations: Option<Vec<Vector3<f32>>>

The rotation for each key frame.

scales: Option<Vec<Vector3<f32>>>

The non uniform scale for each key frame.

weights: Option<Vec<Vec<f32>>>

The morph weights for each key frame.

Implementations

source

impl KeyFrames

source

pub fn rotation(&self, time: f32) -> Option<Quaternion<f32>>

The rotation at the specified time.

source

pub fn translation(&self, time: f32) -> Option<Vector3<f32>>

The translation at the specified time.

source

pub fn scale(&self, time: f32) -> Option<Vector3<f32>>

The scale at the specified time.

source

pub fn transformation(&self, time: f32) -> Matrix4<f32>

The transformation at the specified time.

source

pub fn weights(&self, time: f32) -> Option<Vec<f32>>

The morph weights at the specified time.