Environment

Struct Environment 

pub struct Environment {
    pub irradiance_map: TextureCubeMap,
    pub prefilter_map: TextureCubeMap,
    pub brdf_map: Texture2D,
}
Precalculations of light shining from an environment map (known as image based lighting - IBL). This allows for real-time rendering of ambient light from the environment (see AmbientLight).

Fields

irradiance_map: TextureCubeMap

A cube map used to calculate the diffuse contribution from the environment.

prefilter_map: TextureCubeMap

A cube map used to calculate the specular contribution from the environment. Each mip-map level contain the prefiltered color for a certain surface roughness.

brdf_map: Texture2D

A 2D texture that contain the BRDF lookup tables (LUT).

Implementations

Source

impl Environment

pub fn new(context: &Context, environment_map: &TextureCubeMap) -> Self

Computes the maps needed for image based lighting with lighting coming from the given environment map and using the default Cook-Torrance lighting model.

pub fn new_with_lighting_model( context: &Context, environment_map: &TextureCubeMap, lighting_model: LightingModel, ) -> Self

Computes the maps needed for image based lighting with lighting coming from the given environment map and using the specified lighting model.

pub fn new_with_options( context: &Context, environment_map: &TextureCubeMap, options: EnvironmentOptions, ) -> Self

Computes the maps needed for image based lighting with lighting coming from the given environment map and using the specified EnvironmentOptions.