pub struct PointLight {
pub intensity: f32,
pub color: Srgba,
pub position: Vec3,
pub attenuation: Attenuation,
}Expand description
A light which shines from the given position in all directions.
Fields
intensity: f32The intensity of the light. This allows for higher intensity than 1 which can be used to simulate high intensity light sources like the sun.
color: SrgbaThe base color of the light.
position: Vec3The position of the light.
attenuation: AttenuationThe Attenuation of the light.
Implementations
Sourceimpl PointLight
impl PointLight
Sourcepub fn new(
_context: &Context,
intensity: f32,
color: Srgba,
position: Vec3,
attenuation: Attenuation,
) -> PointLight
pub fn new( _context: &Context, intensity: f32, color: Srgba, position: Vec3, attenuation: Attenuation, ) -> PointLight
Constructs a new point light.