Viewer

Trait Viewer 

pub trait Viewer {
    // Required methods
    fn position(&self) -> Vec3;
    fn view(&self) -> Mat4;
    fn projection(&self) -> Mat4;
    fn viewport(&self) -> Viewport;
    fn z_near(&self) -> f32;
    fn z_far(&self) -> f32;
    fn color_mapping(&self) -> ColorMapping;
    fn tone_mapping(&self) -> ToneMapping;
}
Represents a viewer, usually some kind of camera. The default implementation of this trait is the Camera which should be adequate for most use cases.

Required Methods

fn position(&self) -> Vec3

The position of the viewer.

fn view(&self) -> Mat4

The view matrix which transforms from world space to view space.

fn projection(&self) -> Mat4

The projection matrix which transforms from view space to clip space (2D position on the screen).

fn viewport(&self) -> Viewport

The 2D Viewport of the viewer.

fn z_near(&self) -> f32

Defines the minimum depth in world space.

fn z_far(&self) -> f32

Defines the maximum depth in world space.

fn color_mapping(&self) -> ColorMapping

Defines the ColorMapping applied to the final rendered image.

fn tone_mapping(&self) -> ToneMapping

Defines the ToneMapping applied to the final rendered image.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Viewer + ?Sized> Viewer for &T

Source

impl<T: Viewer + ?Sized> Viewer for &mut T

Source

impl<T: Viewer> Viewer for Arc<T>

Source

impl<T: Viewer> Viewer for Box<T>

Source

impl<T: Viewer> Viewer for Rc<T>

Source

impl<T: Viewer> Viewer for RefCell<T>

Source

impl<T: Viewer> Viewer for RwLock<T>

Implementors