Struct three_d::BlendParameters [−][src]
pub struct BlendParameters {
pub source_rgb_multiplier: BlendMultiplierType,
pub source_alpha_multiplier: BlendMultiplierType,
pub destination_rgb_multiplier: BlendMultiplierType,
pub destination_alpha_multiplier: BlendMultiplierType,
pub rgb_equation: BlendEquationType,
pub alpha_equation: BlendEquationType,
}Expand description
Defines which type of blending to use for a render call. Blending allows combining each color channel of a render call with the color already in the color channels of the render target. This is usually used to simulate transparency.
Fields
source_rgb_multiplier: BlendMultiplierTypesource_alpha_multiplier: BlendMultiplierTypedestination_rgb_multiplier: BlendMultiplierTypedestination_alpha_multiplier: BlendMultiplierTypergb_equation: BlendEquationTypealpha_equation: BlendEquationTypeImplementations
impl BlendParameters[src]
impl BlendParameters[src]pub const TRANSPARENCY: Self[src]
pub const TRANSPARENCY: Self[src]Usual transparency blending parameters.