Struct three_d::ClearState [−][src]
pub struct ClearState {
pub red: Option<f32>,
pub green: Option<f32>,
pub blue: Option<f32>,
pub alpha: Option<f32>,
pub depth: Option<f32>,
}Expand description
Defines which channels (red, green, blue, alpha and depth) to clear when starting to write to a
render target or the screen.
If None then the channel is not cleared and if Some(value) the channel is cleared to that value (the value must be between 0 and 1).
Fields
red: Option<f32>Expand description
Defines the clear value for the red channel.
green: Option<f32>Expand description
Defines the clear value for the green channel.
blue: Option<f32>Expand description
Defines the clear value for the blue channel.
alpha: Option<f32>Expand description
Defines the clear value for the alpha channel.
depth: Option<f32>Expand description
Defines the clear value for the depth channel. A value of 1 means a depth value equal to the far plane and 0 means a depth value equal to the near plane.
Implementations
impl ClearState[src]
impl ClearState[src]Trait Implementations
impl Clone for ClearState[src]
impl Clone for ClearState[src]fn clone(&self) -> ClearState[src]
fn clone(&self) -> ClearState[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for ClearState[src]
impl Debug for ClearState[src]impl Default for ClearState[src]
impl Default for ClearState[src]impl PartialEq<ClearState> for ClearState[src]
impl PartialEq<ClearState> for ClearState[src]fn eq(&self, other: &ClearState) -> bool[src]
fn eq(&self, other: &ClearState) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &ClearState) -> bool[src]
fn ne(&self, other: &ClearState) -> bool[src]This method tests for !=.
impl Copy for ClearState[src]
impl StructuralPartialEq for ClearState[src]