Struct three_d::RenderStates [−][src]
pub struct RenderStates {
pub write_mask: WriteMask,
pub depth_test: DepthTestType,
pub blend: Option<BlendParameters>,
}Expand description
A set of render specific states that has to be specified at each render call.
Fields
write_mask: WriteMaskExpand description
Defines which channels (red, green, blue, alpha and depth) to write to in a render call.
depth_test: DepthTestTypeExpand description
Defines the depth test in a render call. The depth test determines whether or not a fragment from the current render call should be discarded when comparing its depth with the depth of the current fragment.
blend: Option<BlendParameters>Expand description
Defines which type of blending to use for a render call. Blending allows combining each color channel of a render call with the color already in the color channels of the render target. This is usually used to simulate transparency.