Struct three_d::window::FrameInputGenerator
source · pub struct FrameInputGenerator { /* private fields */ }Expand description
Use this to generate FrameInput for a new frame with a custom winit window. FrameInput is automatically generated if using the default Window.
Implementations
sourceimpl FrameInputGenerator
impl FrameInputGenerator
sourcepub fn from_winit_window(window: &Window) -> Self
pub fn from_winit_window(window: &Window) -> Self
Creates a new frame input generator from a winit window.
sourcepub fn generate(&mut self, context: &Context) -> FrameInput
pub fn generate(&mut self, context: &Context) -> FrameInput
Generates FrameInput for a new frame. This should be called each frame and the generated data should only be used for one frame.
sourcepub fn handle_winit_window_event(&mut self, event: &WindowEvent<'_>)
pub fn handle_winit_window_event(&mut self, event: &WindowEvent<'_>)
Handle the WindowEvent generated by a winit event loop.