pub struct HeadlessContext { /* private fields */ }
A headless graphics context, ie. a graphics context that is not associated with any window. For a graphics context associated with a window, see WindowedContext. Can only be created on native, not on web.

Implementations

source

impl HeadlessContext

source

pub fn new() -> Result<Self, HeadlessError>

Creates a new headless graphics context.

Methods from Deref<Target = Context>

source

pub fn program( &self, vertex_shader_source: String, fragment_shader_source: String, callback: impl FnOnce(&Program) ) -> Result<(), CoreError>

👎Deprecated: Use Context::programs

Compiles a Program with the given vertex and fragment shader source and stores it for later use. If it has already been created, then it is just returned.

source

pub fn set_scissor(&self, scissor_box: ScissorBox)

Set the scissor test for this context (see ScissorBox).

source

pub fn set_viewport(&self, viewport: Viewport)

Set the viewport for this context (See Viewport).

source

pub fn set_cull(&self, cull: Cull)

Set the face culling for this context (see Cull).

source

pub fn set_write_mask(&self, write_mask: WriteMask)

Set the write mask for this context (see WriteMask).

source

pub fn set_depth_test(&self, depth_test: DepthTest)

Set the depth test for this context (see DepthTest).

source

pub fn set_blend(&self, blend: Blend)

Set the blend state for this context (see Blend).

source

pub fn set_render_states(&self, render_states: RenderStates)

Set the render states for this context (see RenderStates).

source

pub fn error_check(&self) -> Result<(), CoreError>

Returns an error if an GPU-side error has happened while rendering which can be used to check for errors while developing. Can also be used in production to handle unexpected rendering errors, but do not call it too often to avoid performance problems.