WindowSettings

Struct WindowSettings 

pub struct WindowSettings {
    pub title: String,
    pub min_size: (u32, u32),
    pub max_size: Option<(u32, u32)>,
    pub initial_size: Option<(u32, u32)>,
    pub borderless: bool,
    pub surface_settings: SurfaceSettings,
}
Available on crate feature window only.
Settings for the default Window.

Fields

title: String

The title of the window.

On web this has no effect.

min_size: (u32, u32)

The minimum size of the window (width, height), in logical pixels.

On web this has no effect.

max_size: Option<(u32, u32)>

The maximum size of the window (width, height), in logical pixels. If None is specified, the window can be maximized.

initial_size: Option<(u32, u32)>

The initial size of the window (width, height), in logical pixels. If None is specified, defaults to max_size.

On web, the size will be applied to the [canvas][WindowSettings::canvas], in logical pixels. If None is specified on both this and max_size, the canvas will be resized to the same size as the owner Window’s inner width and height.

borderless: bool

Borderless mode.

On web this has no effect.

surface_settings: SurfaceSettings

Settings related to the surface on where to draw.