Mesh

Struct Mesh 

pub struct Mesh { /* private fields */ }
A triangle mesh Geometry.

Implementations

Source

impl Mesh

pub fn new(context: &Context, cpu_mesh: &CpuMesh) -> Self

Creates a new triangle mesh from the given CpuMesh. All data in the CpuMesh is transfered to the GPU, so make sure to remove all unnecessary data from the CpuMesh before calling this method.

pub fn transformation(&self) -> Mat4

Returns the local to world transformation applied to this mesh.

pub fn set_transformation(&mut self, transformation: Mat4)

Set the local to world transformation applied to this mesh. If any animation method is set using Self::set_animation, the transformation from that method is applied before this transformation.

pub fn set_animation( &mut self, animation: impl Fn(f32) -> Mat4 + Send + Sync + 'static, )

Specifies a function which takes a time parameter as input and returns a transformation that should be applied to this mesh at the given time. To actually animate this mesh, call Geometry::animate at each frame which in turn evaluates the animation function defined by this method. This transformation is applied first, then the local to world transformation defined by Self::set_transformation.

pub fn vertex_count(&self) -> u32

Returns the number of vertices in this mesh.

pub fn indices_mut(&mut self) -> &mut TriangleBuffer

Used for editing the triangle definition in the TriangleBuffer for this mesh. Note: Changing this will possibly ruin the mesh.

pub fn set_positions(&mut self, positions: &[Vec3]) -> Result<(), RendererError>

Update the vertex positions of the mesh. Returns an error if the number of positions does not match the number of vertices in the mesh.

pub fn set_positions_partially( &mut self, offset: u32, positions: &[Vec3], ) -> Result<(), RendererError>

Partially update the vertex positions of the mesh. Returns an error if the number of positions plus the offset is larger than the number of vertices in the mesh.

pub fn positions_mut(&mut self) -> &mut VertexBuffer<Vec3>

👎Deprecated:

use set_positions and set_positions_partially instead

Used for editing the vertex positions. Note: Changing this will possibly ruin the mesh.

pub fn set_normals(&mut self, normals: &[Vec3]) -> Result<(), RendererError>

Update the vertex normals of the mesh. Returns an error if the number of normals does not match the number of vertices in the mesh.

pub fn set_normals_partially( &mut self, offset: u32, normals: &[Vec3], ) -> Result<(), RendererError>

Partially update the vertex normals of the mesh. Returns an error if the number of normals plus the offset is larger than the number of vertices in the mesh or if the normal buffer is missing.

pub fn normals_mut(&mut self) -> &mut Option<VertexBuffer<Vec3>>

👎Deprecated:

use set_normals and set_normals_partially instead

Used for editing the vertex normals. Note: Changing this will possibly ruin the mesh.

pub fn set_uvs(&mut self, uvs: &[Vec2]) -> Result<(), RendererError>

Update the vertex UVs of the mesh. Returns an error if the number of UVs does not match the number of vertices in the mesh.

pub fn set_uvs_partially( &mut self, offset: u32, uvs: &[Vec2], ) -> Result<(), RendererError>

Partially update the vertex UVs of the mesh. Returns an error if the number of UVs plus the offset is larger than the number of vertices in the mesh or if the UV buffer is missing.

pub fn uvs_mut(&mut self) -> &mut Option<VertexBuffer<Vec2>>

👎Deprecated:

use set_uvs and set_uvs_partially instead

Used for editing the vertex uvs. Note: Changing this will possibly ruin the mesh.

pub fn set_tangents(&mut self, tangents: &[Vec4]) -> Result<(), RendererError>

Update the vertex tangents of the mesh. Returns an error if the number of tangents does not match the number of vertices in the mesh.

pub fn set_tangents_partially( &mut self, offset: u32, tangents: &[Vec4], ) -> Result<(), RendererError>

Partially update the vertex tangents of the mesh. Returns an error if the number of tangents plus the offset is larger than the number of vertices in the mesh or if the tangent buffer is missing.

pub fn tangents_mut(&mut self) -> &mut Option<VertexBuffer<Vec4>>

👎Deprecated:

use set_tangents and set_tangents_partially instead

Used for editing the vertex tangents. Note: Changing this will possibly ruin the mesh.

pub fn set_colors(&mut self, colors: &[Vec4]) -> Result<(), RendererError>

Update the vertex colors of the mesh. Returns an error if the number of colors does not match the number of vertices in the mesh.

pub fn set_colors_partially( &mut self, offset: u32, colors: &[Vec4], ) -> Result<(), RendererError>

Partially update the vertex colors of the mesh. Returns an error if the number of colors plus the offset is larger than the number of vertices in the mesh or if the colors buffer is missing.

pub fn colors_mut(&mut self) -> &mut Option<VertexBuffer<Vec4>>

👎Deprecated:

use set_colors and set_colors_partially instead

Used for editing the vertex colors. Note: Changing this will possibly ruin the mesh.