pub struct EnvironmentOptions {
pub lighting_model: LightingModel,
pub irradiance_map_size: u32,
pub irradiance_sample_count: u32,
pub prefilter_map_size: u32,
pub prefilter_map_max_mip_levels: u32,
pub prefilter_sample_count: u32,
pub brdf_map_size: u32,
pub brdf_sample_count: u32,
}Expand description
Options used when generating an Environment, ie. when precalculating lighting from an environment map.
Fields
lighting_model: LightingModelThe lighting model used for the precalculation.
irradiance_map_size: u32The texture size of the irradiance map.
irradiance_sample_count: u32The number of samples used when generating the irradiance map.
prefilter_map_size: u32The texture size of the prefilter map.
prefilter_map_max_mip_levels: u32The number of mip levels used when generating the prefilter map.
prefilter_sample_count: u32The number of samples used when generating the prefilter map.
brdf_map_size: u32The texture size of the BRDF map.
brdf_sample_count: u32The number of samples used when generating the BRDF map.